@@ -20,7 +20,6 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import encodeutils
 from oslo_utils import uuidutils
-import six
 import tenacity
 import tooz.coordination
 
@@ -33,14 +32,11 @@ OPTS = [
                     'left empty, alarm evaluation won\'t do workload '
                     'partitioning and will only function correctly if a '
                     'single instance of the service is running.'),
-    cfg.FloatOpt('heartbeat',
+    cfg.FloatOpt('heartbeat_interval',
                  default=1.0,
+                 deprecated_name='heartbeat',
                  help='Number of seconds between heartbeats for distributed '
                       'coordination.'),
-    cfg.FloatOpt('check_watchers',
-                 default=10.0,
-                 help='Number of seconds between checks to see if group '
-                      'membership has changed'),
     cfg.IntOpt('retry_backoff',
                default=1,
                help='Retry backoff factor when retrying to connect with'
@@ -73,7 +69,7 @@ class HashRing(object):
         self._sorted_keys = []
 
         for node in nodes:
-            for r in six.moves.range(replicas):
+            for r in range(replicas):
                 hashed_key = self._hash('%s-%s' % (node, r))
                 self._ring[hashed_key] = node
                 self._sorted_keys.append(hashed_key)
