@@ -18,7 +18,7 @@ import os.path
 from alembic import command
 from alembic import config
 from alembic import migration
-from oslo_db.sqlalchemy import session as db_session
+from oslo_db.sqlalchemy import enginefacade
 from oslo_db.sqlalchemy import utils as oslo_sql_utils
 from oslo_log import log
 from oslo_utils import importutils
@@ -106,11 +106,16 @@ class Connection(base.Connection):
         # in storage.__init__.get_connection_from_config function
         options = dict(conf.database.items())
         options['max_retries'] = 0
+        # FIXME(stephenfin): Remove this (and ideally use of
+        # LegacyEngineFacade) asap since it's not compatible with SQLAlchemy
+        # 2.0
+        options['autocommit'] = True
         # oslo.db doesn't support options defined by Aodh
         for opt in storage.OPTS:
             options.pop(opt.name, None)
-        self._engine_facade = db_session.EngineFacade(self.dress_url(url),
-                                                      **options)
+        self._engine_facade = enginefacade.LegacyEngineFacade(
+            self.dress_url(url),
+            **options)
 
         if osprofiler_sqlalchemy:
             osprofiler_sqlalchemy.add_tracing(sqlalchemy,
@@ -123,7 +128,7 @@ class Connection(base.Connection):
         # If no explicit driver has been set, we default to pymysql
         if url.startswith("mysql://"):
             url = sqlalchemy_url.make_url(url)
-            url.drivername = "mysql+pymysql"
+            url = url.set(drivername="mysql+pymysql")
             return str(url)
         return url
 
@@ -398,21 +403,23 @@ class Connection(base.Connection):
             alarm_change_row.update(alarm_change)
             session.add(alarm_change_row)
 
-    def clear_expired_alarm_history_data(self, alarm_history_ttl):
+    def clear_expired_alarm_history_data(self, ttl, max_count=100):
         """Clear expired alarm history data from the backend storage system.
 
         Clearing occurs according to the time-to-live.
 
-        :param alarm_history_ttl: Number of seconds to keep alarm history
-                                  records for.
+        :param ttl: Number of seconds to keep alarm history records for.
+        :param max_count: Number of records to delete.
         """
         session = self._engine_facade.get_session()
         with session.begin():
-            valid_start = (timeutils.utcnow() -
-                           datetime.timedelta(seconds=alarm_history_ttl))
-            deleted_rows = (session.query(models.AlarmChange)
-                            .filter(models.AlarmChange.timestamp < valid_start)
-                            .delete())
+            end = timeutils.utcnow() - datetime.timedelta(seconds=ttl)
+            alarm_history_q = (session.query(models.AlarmChange.event_id)
+                               .filter(models.AlarmChange.timestamp < end))
+            event_ids = [i[0] for i in alarm_history_q.limit(max_count)]
+            deleted_rows = session.query(models.AlarmChange).filter(
+                models.AlarmChange.event_id.in_(event_ids)
+            ).delete(synchronize_session="fetch")
             LOG.info("%d alarm histories are removed from database",
                      deleted_rows)
 
